﻿using Windows.System;
using Windows.UI.Core;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Input;

namespace SimpleGridSplitter
{
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        void OnThumbDragStarted(object sender, DragStartedEventArgs args)
        {
            OnDragStart((Thumb)sender);
        }

        void OnThumbDragDelta(object sender, DragDeltaEventArgs args)
        {
            OnDragDelta((Thumb)sender, args.HorizontalChange);
        }

        void OnThumbGotFocus(object sender, RoutedEventArgs args)
        {
            OnDragStart((Thumb)sender);
        }

        void OnThumbKeyDown(object sender, KeyRoutedEventArgs args)
        {
            if (args.Key == VirtualKey.Left || args.Key == VirtualKey.Right)
                OnDragDelta((Thumb)sender, args.Key == VirtualKey.Left ? -5 : 5);
        }

        void OnDragStart(Thumb thumb)
        {
            Grid grid = (Grid)thumb.Parent;
            ColumnDefinition leftColDef = grid.ColumnDefinitions[0];
            ColumnDefinition rightColDef = grid.ColumnDefinitions[2];

            leftColDef.Width =
                new GridLength(leftColDef.ActualWidth, GridUnitType.Star);
            rightColDef.Width =
                new GridLength(rightColDef.ActualWidth, GridUnitType.Star);
        }

        void OnDragDelta(Thumb thumb, double change)
        {
            Grid grid = (Grid)thumb.Parent;
            ColumnDefinition leftColDef = grid.ColumnDefinitions[0];
            ColumnDefinition rightColDef = grid.ColumnDefinitions[2];

            leftColDef.Width =
                new GridLength(leftColDef.Width.Value + change, GridUnitType.Star);
            rightColDef.Width =
                new GridLength(rightColDef.Width.Value - change, GridUnitType.Star);
        }

        void OnThumbPointerEntered(object sender, PointerRoutedEventArgs args)
        {
            Window.Current.CoreWindow.PointerCursor =
                new CoreCursor(CoreCursorType.SizeWestEast, 0);
        }

        void OnThumbPointerExited(object sender, PointerRoutedEventArgs args)
        {
            Window.Current.CoreWindow.PointerCursor =
                new CoreCursor(CoreCursorType.SizeWestEast, 0);
        }
    }
}
